==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/eo.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumentoj",
"Can't create document" => "Ne povas kreiĝi dokumento",
"You don't have permission to rename this document" => "Vi ne havas permeson alinomigi ĉi tiun dokumenton",
"Directory saved successfully." => "La dosierujo konserviĝis sukcese.",
"An error occurred while changing directory." => "Eraro okazis dum ŝanĝo de dosierujo.",
"Saved" => "Konservita",
"Saving..." => "Konservante...",
"Failed to load documents." => "Malsukcesis ŝargo de dokumentoj.",
"No connection to server. Trying to reconnect." => "Ne estas konekto al servilo. Provu rekonekti.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Laso de ĉi tiu paĝo en reĝimo Redaktilo povas kaŭzi nekonservotaj datumoj. Rekomendatas uzo de la butono “Fermi” anstataŭe.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Malsukcesis ŝargo de ĉi tiu dokumento. Bonvolu kontroli ĉu ĝi malfermeblas per malena odt-redaktilo. Ĉi tio povas ankaŭ signifi, ke ĝi malkunhaviĝis aŭ foriĝis lastatempe.",
"Save" => "Konservi",
"Loading documents..." => "Ŝargante dokumentojn...",
"'.' is an invalid file name." => "'.' ne estas valida dosiernomo.",
"File name cannot be empty." => "Dosiernomo devas ne malpleni.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Nevalida nomo: “\\”, “/”, “<”, “>”, “:”, “\"”, “|”, “?” kaj “*” ne permesatas.",
"Align Left" => "Ĝisrandigi maldekstren",
"Alignment" => "Ĝisrandigo",
"Align Right" => "Ĝisrandigi dekstren",
"Annotate" => "Prinoti",
"Background" => "Fono",
"Bold" => "Grasa",
"Bottom" => "Malsupro",
"Cancel" => "Nuligi",
"Center" => "Centrigi",
"Clone" => "Kloni",
"Clone this Style" => "Kloni ĉi tiun stilon",
"Close" => "Fermi",
"Color" => "Koloro",
"Create" => "Krei",
"Decrease Indent" => "Malgrindigi krommarĝenon",
"Default Style" => "Defaŭlta stilo",
"Delete" => "Forigi",
"Family" => "Familio",
"Font" => "Tiparo",
"Font Effects" => "Tiparaj efektoj",
"Format" => "Aranĝo",
"Increase Indent" => "Grandigi krommarĝenon",
"Insert Image" => "Enigi bildon",
"Invite Members" => "Inviti membrojn",
"Italic" => "Kursiva",
"Justified" => "Ĝis ambaŭ randoj",
"Justify" => "Ĝisambaŭrandigi",
"Left" => "Maldekstren",
"Loading" => "Ŝargante",
"Members" => "Membroj",
"New Name:" => "Nova nomo:",
"OK" => "Akcepti",
"Open" => "Malfermi",
"Options" => "Malneproj",
"Paragraph..." => "Alineo...",
"Paragraph Styles" => "Alineaj stiloj",
"Redo" => "Refari",
"Right" => "Dekstren",
"Size" => "Grando",
"Spacing" => "Interspaco",
"Strikethrough" => "Trastreko",
"Style" => "Stilo",
"Text" => "Teksto",
"Top" => "Supro",
"Underline" => "Substreko",
"Undo" => "Malfari",
"Unknown Author" => "Nekonata verkinto",
"Edit" => "Redakti",
"Share" => "Kunhavigi",
"guest" => "gasto",
"MS Word support (requires openOffice/libreOffice)" => "Kongruo kun MS Word (postuliĝas openOffice/libreOffice)",
"Local" => "Loka",
"External" => "Malena",
"Disabled" => "Malkapabligita",
"Server URL" => "Servila URL",
"New document" => "Nova dokumento",
"Upload (max. %s)" => "Alŝuti (maks. %s)",
"Upload" => "Alŝuti",
"Save new documents to" => "Konservi novajn dokumentojn en",
"Wrong password. Please retry." => "La pasvorto malĝustas. Bonvolu reprovi.",
"Password" => "Pasvorto",
"Guest %s" => "Gasto %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Ĉi tiu ligilo eksvalidiĝis aŭ neniam ekzistis. Bonvolu kontakti la personon, kiu kunhavigis ĝin kun vi, por detaloj.",
"Advanced feature-set" => "Altanivela funkciaro",
"(Unstable)" => "(nestabila)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/eo.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumentoj",
"Can't create document" => "Ne povas kreiĝi dokumento",
"You don't have permission to rename this document" => "Vi ne havas permeson alinomigi ĉi tiun dokumenton",
"Directory saved successfully." => "La dosierujo konserviĝis sukcese.",
"An error occurred while changing directory." => "Eraro okazis dum ŝanĝo de dosierujo.",
"Saved" => "Konservita",
"Saving..." => "Konservante...",
"Failed to load documents." => "Malsukcesis ŝargo de dokumentoj.",
"No connection to server. Trying to reconnect." => "Ne estas konekto al servilo. Provu rekonekti.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Laso de ĉi tiu paĝo en reĝimo Redaktilo povas kaŭzi nekonservotaj datumoj. Rekomendatas uzo de la butono “Fermi” anstataŭe.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Malsukcesis ŝargo de ĉi tiu dokumento. Bonvolu kontroli ĉu ĝi malfermeblas per malena odt-redaktilo. Ĉi tio povas ankaŭ signifi, ke ĝi malkunhaviĝis aŭ foriĝis lastatempe.",
"Save" => "Konservi",
"Loading documents..." => "Ŝargante dokumentojn...",
"'.' is an invalid file name." => "'.' ne estas valida dosiernomo.",
"File name cannot be empty." => "Dosiernomo devas ne malpleni.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Nevalida nomo: “\\”, “/”, “<”, “>”, “:”, “\"”, “|”, “?” kaj “*” ne permesatas.",
"Align Left" => "Ĝisrandigi maldekstren",
"Alignment" => "Ĝisrandigo",
"Align Right" => "Ĝisrandigi dekstren",
"Annotate" => "Prinoti",
"Background" => "Fono",
"Bold" => "Grasa",
"Bottom" => "Malsupro",
"Cancel" => "Nuligi",
"Center" => "Centrigi",
"Clone" => "Kloni",
"Clone this Style" => "Kloni ĉi tiun stilon",
"Close" => "Fermi",
"Color" => "Koloro",
"Create" => "Krei",
"Decrease Indent" => "Malgrindigi krommarĝenon",
"Default Style" => "Defaŭlta stilo",
"Delete" => "Forigi",
"Family" => "Familio",
"Font" => "Tiparo",
"Font Effects" => "Tiparaj efektoj",
"Format" => "Aranĝo",
"Increase Indent" => "Grandigi krommarĝenon",
"Insert Image" => "Enigi bildon",
"Invite Members" => "Inviti membrojn",
"Italic" => "Kursiva",
"Justified" => "Ĝis ambaŭ randoj",
"Justify" => "Ĝisambaŭrandigi",
"Left" => "Maldekstren",
"Loading" => "Ŝargante",
"Members" => "Membroj",
"New Name:" => "Nova nomo:",
"OK" => "Akcepti",
"Open" => "Malfermi",
"Options" => "Malneproj",
"Paragraph..." => "Alineo...",
"Paragraph Styles" => "Alineaj stiloj",
"Redo" => "Refari",
"Right" => "Dekstren",
"Size" => "Grando",
"Spacing" => "Interspaco",
"Strikethrough" => "Trastreko",
"Style" => "Stilo",
"Text" => "Teksto",
"Top" => "Supro",
"Underline" => "Substreko",
"Undo" => "Malfari",
"Unknown Author" => "Nekonata verkinto",
"Shared" => "Kunhavata",
"Error" => "Eraro",
"Error while sharing" => "Eraro dum kunhavigo",
"Error while unsharing" => "Eraro dum malkunhavigo",
"Error while changing permissions" => "Eraro dum ŝanĝo de permesoj",
"Shared with you and the group {group} by {owner}" => "Kunhavigita kun vi kaj la grupo {group} de {owner}",
"Shared with you by {owner}" => "Kunhavigita kun vi de {owner}",
"Share" => "Kunhavigi",
"Share link" => "Kunhavigi ligilon",
"Password protect" => "Protekti per pasvorto",
"Password" => "Pasvorto",
"Email link to person" => "Retpoŝti la ligilon al ulo",
"Send" => "Sendi",
"Set expiration date" => "Agordi limdaton",
"Expiration" => "Eksvalidiĝo",
"Expiration date" => "Limdato",
"group" => "grupo",
"Resharing is not allowed" => "Rekunhavigo ne permesatas",
"Shared in {item} with {user}" => "Kunhavigita en {item} kun {user}",
"Unshare" => "Malkunhavigi",
"notify by email" => "avizi per retpoŝto",
"can share" => "kunhavebla",
"can edit" => "povas redakti",
"access control" => "alirkontrolo",
"create" => "krei",
"delete" => "forigi",
"Password protected" => "Protektita per pasvorto",
"Error unsetting expiration date" => "Eraro dum malagordado de limdato",
"Error setting expiration date" => "Eraro dum agordado de limdato",
"Sending ..." => "Sendante...",
"Email sent" => "La retpoŝtaĵo sendiĝis",
"Warning" => "Averto",
"Edit" => "Redakti",
"guest" => "gasto",
"MS Word support (requires openOffice/libreOffice)" => "Kongruo kun MS Word (postuliĝas openOffice/libreOffice)",
"Local" => "Loka",
"External" => "Malena",
"Disabled" => "Malkapabligita",
"Server URL" => "Servila URL",
"New document" => "Nova dokumento",
"Upload (max. %s)" => "Alŝuti (maks. %s)",
"Upload" => "Alŝuti",
"Save new documents to" => "Konservi novajn dokumentojn en",
"Wrong password. Please retry." => "La pasvorto malĝustas. Bonvolu reprovi.",
"Guest %s" => "Gasto %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Ĉi tiu ligilo eksvalidiĝis aŭ neniam ekzistis. Bonvolu kontakti la personon, kiu kunhavigis ĝin kun vi, por detaloj.",
"Advanced feature-set" => "Altanivela funkciaro",
"(Unstable)" => "(nestabila)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
